@@ -1,6 +1,9 @@
 package mackerel
 
-import "net/http"
+import (
+	"context"
+	"net/http"
+)
 
 // GraphDefsParam parameters for posting graph definitions
 type GraphDefsParam struct {
@@ -25,6 +28,6 @@ func (c *Client) CreateGraphDefs(graphDefs []*GraphDefsParam) error {
 
 // DeleteGraphDef deletes a graph definition.
 func (c *Client) DeleteGraphDef(name string) error {
-	_, err := requestJSON[any](c, http.MethodDelete, "/api/v0/graph-defs", map[string]string{"name": name})
+	_, err := requestJSON[any](context.TODO(), c, http.MethodDelete, "/api/v0/graph-defs", map[string]string{"name": name})
 	return err
 }
